==> Paws-0.34.tar.gz: Paws-0.34/lib/Paws/DS/CancelSchemaExtension.pm <==

package Paws::DS::CancelSchemaExtension;
  use Moose;
  has DirectoryId => (is => 'ro', isa => 'Str', required => 1);
  has SchemaExtensionId => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'CancelSchemaExtension');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::DS::CancelSchemaExtensionResult');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::DS::CancelSchemaExtension - Arguments for method CancelSchemaExtension on Paws::DS

=head1 DESCRIPTION

This class represents the parameters used for calling the method CancelSchemaExtension on the 
AWS Directory Service service. Use the attributes of this class
as arguments to method CancelSchemaExtension.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to CancelSchemaExtension.

As an example:

  $service_obj->CancelSchemaExtension(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES


=head2 B<REQUIRED> DirectoryId => Str

The identifier of the directory whose schema extension will be
canceled.



=head2 B<REQUIRED> SchemaExtensionId => Str

The identifier of the schema extension that will be canceled.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method CancelSchemaExtension in L<Paws::DS>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.46.tar.gz: Paws-0.46/lib/Paws/DS/CancelSchemaExtension.pm <==

package Paws::DS::CancelSchemaExtension;
  use Moose;
  has DirectoryId => (is => 'ro', isa => 'Str', required => 1);
  has SchemaExtensionId => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'CancelSchemaExtension');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::DS::CancelSchemaExtensionResult');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::DS::CancelSchemaExtension - Arguments for method CancelSchemaExtension on L<Paws::DS>

=head1 DESCRIPTION

This class represents the parameters used for calling the method CancelSchemaExtension on the
L<AWS Directory Service|Paws::DS> service. Use the attributes of this class
as arguments to method CancelSchemaExtension.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to CancelSchemaExtension.

=head1 SYNOPSIS

    my $ds = Paws->service('DS');
    my $CancelSchemaExtensionResult = $ds->CancelSchemaExtension(
      DirectoryId       => 'MyDirectoryId',
      SchemaExtensionId => 'MySchemaExtensionId',

    );

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/ds/CancelSchemaExtension>

=head1 ATTRIBUTES


=head2 B<REQUIRED> DirectoryId => Str

The identifier of the directory whose schema extension will be
canceled.



=head2 B<REQUIRED> SchemaExtensionId => Str

The identifier of the schema extension that will be canceled.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method CancelSchemaExtension in L<Paws::DS>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut
